summaryrefslogtreecommitdiffstats
path: root/libksirtet/lib/pline.h
diff options
context:
space:
mode:
Diffstat (limited to 'libksirtet/lib/pline.h')
-rw-r--r--libksirtet/lib/pline.h21
1 files changed, 12 insertions, 9 deletions
diff --git a/libksirtet/lib/pline.h b/libksirtet/lib/pline.h
index d9969264..9cef8d29 100644
--- a/libksirtet/lib/pline.h
+++ b/libksirtet/lib/pline.h
@@ -13,13 +13,14 @@
class TQPushButton;
/** Internal class : display a "player line" in netmeeting. */
-class MeetingLine : public QFrame
+class MeetingLine : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
MeetingLine(bool isOwner, bool readerIsServer, bool serverLine,
- TQWidget *parent, const char *name = 0);
+ TQWidget *tqparent, const char *name = 0);
MeetingCheckBox::Type type() const { return tcb->type(); }
void setType(MeetingCheckBox::Type type) { tcb->setType(type); }
@@ -48,15 +49,16 @@ class MeetingLine : public QFrame
TQLineEdit *qle;
};
-class PlayerLine : public QFrame
+class PlayerLine : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
PlayerLine(PlayerComboBox::Type type, const TQString &txt,
bool humanSetting, bool AISetting,
bool canBeEmpty, bool acceptAI,
- TQWidget *parent = 0, const char *name = 0);
+ TQWidget *tqparent = 0, const char *name = 0);
PlayerComboBox::Type type() const { return pcb->type(); }
TQString name() const { return edit->text(); }
@@ -78,18 +80,19 @@ class PlayerLine : public QFrame
};
/** Internal class : scrolable list of widgets. */
-class GWidgetList : public QWidget
+class GWidgetList : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
- GWidgetList(uint interval, TQWidget *parent = 0, const char * name = 0);
+ GWidgetList(uint interval, TQWidget *tqparent = 0, const char * name = 0);
void remove(uint i);
uint size() const { return widgets.count(); }
protected:
/** The widget must be created with this widget as parent. */
void append(TQWidget *);
TQWidget *widget(uint i) { return widgets.at(i); }
@@ -102,8 +105,8 @@ template <class Type>
class WidgetList : public GWidgetList
{
public:
- WidgetList(uint interval, TQWidget *parent=0, const char *name=0)
- : GWidgetList(interval, parent, name) {}
+ WidgetList(uint interval, TQWidget *tqparent=0, const char *name=0)
+ : GWidgetList(interval, tqparent, name) {}
void append(Type *w) { GWidgetList::append(w); }
Type *widget(uint i) { return (Type *)GWidgetList::widget(i); }
@@ -78,18 +80,19 @@ class PlayerLine : public QFrame
uint size() const { return widgets.count(); }
protected:
- /** The widget must be created with this widget as parent. */
+ /** The widget must be created with this widget as tqparent. */
void append(TQWidget *);
TQWidget *widget(uint i) { return widgets.at(i); }